"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const critic = require("dts-critic");
const Lint = require("tslint");
const util_1 = require("../util");
class Rule extends Lint.Rules.AbstractRule {
    apply(sourceFile) {
        return this.applyWithFunction(sourceFile, walk);
    }
}
Rule.metadata = {
    ruleName: "npm-naming",
    description: "Ensure that package name and DefinitelyTyped header match npm package info.",
    optionsDescription: "Not configurable.",
    options: null,
    type: "functionality",
    typescriptOnly: true,
};
exports.Rule = Rule;
function walk(ctx) {
    const { sourceFile } = ctx;
    const { text } = sourceFile;
    const lookFor = (search, explanation) => {
        const idx = text.indexOf(search);
        if (idx !== -1) {
            ctx.addFailureAt(idx, search.length, util_1.failure(Rule.metadata.ruleName, explanation));
        }
    };
    if (util_1.isMainFile(sourceFile.fileName, /*allowNested*/ false)) {
        try {
            critic(sourceFile.fileName);
        }
        catch (e) {
            // TODO: dts-critic should
            // 1. not really be using exceptions, but lists
            // 2. export an error code enum
            // 3. add an errorCode property to the exception (or return value)
            if (e.message.indexOf("d.ts file must have a matching npm package") > -1 ||
                e.message.indexOf("must match a version that exists on npm") > -1 ||
                e.message.indexOf("The non-npm package") > -1) {
                lookFor("// Type definitions for", e.message);
            }
            else if (e.message.indexOf("export default") > -1) {
                lookFor("export default", e.message);
            }
            else {
                // should be unused!
                ctx.addFailureAt(0, 1, e.message);
            }
        }
    }
    // Don't recur, we're done.
}
//# sourceMappingURL=npmNamingRule.js.map